@@ -15,63 +15,47 @@ test_that("update_mallows works", {
     smc_options = set_smc_options(n_particles = 10)
   )
 
+  expect_error(
+    update_mallows(model = mod_init, new_data = data_second_batch),
+    "new_data must be an object of class BayesMallowsData"
+  )
+
   pi <- compute_posterior_intervals(mod_second)
-  expect_equal(pi$hpdi, "[0.331,0.771]")
-  expect_equal(mod_second$alpha$value[[9]], 0.528698473629568)
+  expect_equal(pi$hpdi, "[0.423,0.753]")
+  expect_equal(mod_second$alpha$value[[9]], 0.753246865159393)
 
   data_third_batch <- potato_visual[9:12, ]
   mod_final <- update_mallows(
     model = mod_second, new_data = setup_rank_data(rankings = data_third_batch)
   )
 
-  expect_equal(mod_final$rho$value[169], 17)
+  expect_equal(mod_final$rho$value[169], 18)
 
-  # Need this because random numbers don't reproduce exactly on M1
-  skip_on_os("mac", arch = "aarch64")
-  potato_top_10 <- ifelse(potato_visual[1:10, ] > 10, NA_real_,
-    potato_visual[1:10, ]
-  )
-  potato_top_12 <- ifelse(potato_visual[1:10, ] > 12, NA_real_,
-    potato_visual[1:10, ]
-  )
-  potato_top_14 <- ifelse(potato_visual[1:10, ] > 14, NA_real_,
-    potato_visual[1:10, ]
-  )
-
-  user_ids <- rownames(potato_visual[1:10, ])
-
-  mod_init <- compute_mallows(
-    data = setup_rank_data(rankings = potato_top_10, user_ids = user_ids),
-    compute_options = set_compute_options(nmc = 100, burnin = 5)
+  expect_error(
+    update_mallows(model = mod_second, new_data = data_third_batch),
+    "new_data must be an object of class BayesMallowsData"
   )
+})
 
+test_that("update_mallows can start from prior", {
+  set.seed(1)
+  prior_samples <- sample_prior(100, 20, set_priors(gamma = 2, lambda = .1))
   mod1 <- update_mallows(
-    model = mod_init,
-    new_data = setup_rank_data(rankings = potato_top_12, user_ids = user_ids),
-    smc_options = set_smc_options(n_particles = 20),
-    compute_options = set_compute_options(aug_method = "pseudo")
+    prior_samples,
+    new_data = setup_rank_data(potato_visual[1, , drop = FALSE]),
+    smc_options = set_smc_options(n_particles = 100)
   )
 
-  expect_equal(mod1$alpha$value[[13]], 0.544567207683911)
+  expect_error(
+    update_mallows(prior_samples, new_data = potato_visual[1, , drop = FALSE]),
+    "new_data must be an object of class BayesMallowsData"
+  )
 
   mod2 <- update_mallows(
-    model = mod1,
-    new_data = setup_rank_data(rankings = potato_top_14, user_ids = user_ids)
+    mod1,
+    new_data = setup_rank_data(potato_visual[2, , drop = FALSE])
   )
-
-  expect_s3_class(mod2, "SMCMallows")
-  potato_new <- potato_visual[11:12, ]
-  user_ids <- rownames(potato_new)
-
-  mod_final <- update_mallows(
-    model = mod2,
-    new_data = setup_rank_data(rankings = potato_new, user_ids = user_ids)
-  )
-
-  expect_s3_class(mod_final, "SMCMallows")
-  skip_on_cran()
-  expect_equal(mod2$rho$value[[300]], 2)
-  expect_equal(mod_final$rho$value[[300]], 3)
+  expect_equal(mod2$alpha_samples[[56]], 3.51628380350389)
 })
 
 test_that("update_mallows handles estimated partition function", {
